@@ -1,6 +1,7 @@
 from .janus import Janus
 from .metis import File, Folder, Metis
-from .magma import Magma
+from .magma import Magma, Model, Template, Attribute, UpdateRequest, QueryRequest
 from .auth import TokenAuth, SigAuth
+from .etna_base import EtnaSession
 
 from . import utils
